@@ -9,6 +9,77 @@
 
 # nocov
 
+make_naive_Bayes_naivebayes <- function() {
+  parsnip::set_model_engine("naive_Bayes", "classification", "naivebayes")
+  parsnip::set_dependency("naive_Bayes", "naivebayes", "naivebayes")
+
+  parsnip::set_model_arg(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    parsnip = "smoothness",
+    original = "adjust",
+    func = list(pkg = "dials", fun = "smoothness"),
+    has_submodel = FALSE
+  )
+
+  parsnip::set_model_arg(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    parsnip = "Laplace",
+    original = "laplace",
+    func = list(pkg = "dials", fun = "Laplace"),
+    has_submodel = FALSE
+  )
+
+  parsnip::set_fit(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    mode = "classification",
+    value = list(
+      interface = "data.frame",
+      protect = c("x", "y"),
+      func = c(pkg = "naivebayes", fun = "naive_bayes"),
+      defaults = list(usekernel = TRUE)
+    )
+  )
+
+
+  parsnip::set_pred(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    mode = "classification",
+    type = "class",
+    value = list(
+      pre = NULL,
+      post = NULL,
+      func = c(fun = "predict"),
+      args =
+        list(
+          object = quote(object$fit),
+          newdata = quote(new_data)
+        )
+    )
+  )
+
+  parsnip::set_pred(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    mode = "classification",
+    type = "prob",
+    value = list(
+      pre = NULL,
+      post = prob_matrix_to_tibble,
+      func = c(fun = "predict"),
+      args =
+        list(
+          object = quote(object$fit),
+          newdata = quote(new_data),
+          type = "prob"
+        )
+    )
+  )
+}
+
 make_naive_Bayes_klaR <- function() {
   parsnip::set_new_model("naive_Bayes")
 
