@@ -194,7 +194,7 @@ test_that('missing data', {
 test_that('api errors', {
   expect_error(
     naive_Bayes() %>% set_engine("lda"),
-    "engine 'lda' is not availble"
+    regexp = "Engine 'lda' is not available"
   )
 })
 
